==> glpi_0.78.3.orig.tar.gz: glpi/front/notificationmailsetting.form.php <==
<?php
/*
 * @version $Id: notificationmailsetting.form.php 11692 2010-06-13 15:00:51Z walid $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

checkRight("config", "w");
$notificationmail = new NotificationMailSetting();

if (!empty($_POST["test_smtp_send"])) {
   NotificationMail::testNotification();
   glpi_header($_SERVER['HTTP_REFERER']);

} else if (!empty($_POST["update"])) {
   $config = new Config;
   $config->update($_POST);
   glpi_header($_SERVER['HTTP_REFERER']);
}

commonHeader($LANG['setup'][704], $_SERVER['PHP_SELF'],"config","mailing","config");

$notificationmail->showForm(1);

commonFooter();
?>

==> glpi_0.80.5.orig.tar.gz: glpi/front/notificationmailsetting.form.php <==
<?php
/*
 * @version $Id: notificationmailsetting.form.php 14684 2011-06-11 06:32:40Z remi $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2011 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

checkRight("config", "w");
$notificationmail = new NotificationMailSetting();

if (!empty($_POST["test_smtp_send"])) {
   NotificationMail::testNotification();
   glpi_header($_SERVER['HTTP_REFERER']);
} else if (!empty($_POST["update"])) {
   $config = new Config;
   $config->update($_POST);
   glpi_header($_SERVER['HTTP_REFERER']);
}

commonHeader($LANG['setup'][704], $_SERVER['PHP_SELF'],"config","mailing","config");

$notificationmail->showForm(1);

commonFooter();
?>
